summaryrefslogtreecommitdiff
path: root/src/lib/player.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/lib/player.h')
-rw-r--r--src/lib/player.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/lib/player.h b/src/lib/player.h
index 85d750f6f..2261f66ea 100644
--- a/src/lib/player.h
+++ b/src/lib/player.h
@@ -62,10 +62,11 @@ public:
/** Emitted when a video frame is ready.
* First parameter is the video image.
* Second parameter is the eye(s) that should see this image.
* Third parameter is true if the image is the same as the last one that was emitted.
* Fourth parameter is the time.
*/
- boost::signals2::signal<void (boost::shared_ptr<const Image>, Eyes, bool, Time)> Video;
+ boost::signals2::signal<void (boost::shared_ptr<const Image>, Eyes, ColourConversion, bool, Time)> Video;
/** Emitted when some audio data is ready */
boost::signals2::signal<void (boost::shared_ptr<const AudioBuffers>, Time)> Audio;
@@ -62,10 +62,11 @@ public:
* First parameter is the video image.
* Second parameter is the eye(s) that should see this image.
- * Third parameter is true if the image is the same as the last one that was emitted.
- * Fourth parameter is the time.
+ * Third parameter is the colour conversion that should be used for this image.
+ * Fourth parameter is true if the image is the same as the last one that was emitted.
+ * Fifth parameter is the time.
*/